package com.ruoyi.web.controller.system;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysMenu;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.domain.model.LoginBody;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.framework.web.service.SysLoginService;
import com.ruoyi.framework.web.service.SysPermissionService;
import com.ruoyi.system.mapper.SysMenuMapper;
import com.ruoyi.system.mapper.SysRoleMapper;
import com.ruoyi.system.service.ISysMenuService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * 登录验证
 * 
 * @author ruoyi
 */
@RestController
public class SysLoginController
{
    @Resource
    private SysLoginService loginService;

    @Resource
    private ISysMenuService menuService;

    @Resource
    private SysPermissionService permissionService;

    @Resource
    private SysRoleMapper roleMapper;

    @Resource
    private SysMenuMapper menuMapper;

    /**
     * 登录方法
     * 
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public AjaxResult login(@RequestBody LoginBody loginBody)
    {
        AjaxResult ajax = AjaxResult.success();
        // 生成令牌
        String token = loginService.login(loginBody.getId(), loginBody.getPassword(), loginBody.getCode(),
                loginBody.getUuid());
        ajax.put(Constants.TOKEN, token);
        return ajax;
    }

    /**
     * 获取用户信息
     * 
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public AjaxResult getInfo()
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);
        AjaxResult ajax = AjaxResult.success();
        ajax.put("user", user);
        if (user.getRoleId().contains("R05") || user.getRoleId().contains("R06")){
            Set<String> a= new HashSet<>();
            a.add("admin");
            ajax.put("roles",a);
        }
        ajax.put("permissions", permissions);
        return ajax;
    }

    /**
     * 获取路由信息
     * 
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public AjaxResult getRouters()
    {
        String userId = SecurityUtils.getUserId();
        String s = roleMapper.selectRoleIDsByUserName(userId);
        Set<String> menuIDs = new HashSet<>();
        for (String roleID : s.split("\\|")) {
            String menuIds = menuMapper.selectMenuIDsByRoleId(roleID);
            menuIDs.addAll(Arrays.asList(menuIds.split("\\|")));
        }
        List<String> menuIdscollect = menuIDs.stream().sorted().collect(Collectors.toList());
        List<SysMenu> menus = menuService.selectMenuTreeByUserId(userId);
//        List<SysMenu> menusByMenuID = new ArrayList<>();
//        if(menus == null || menus.isEmpty()){
//            for (String s1 : menuIdscollect) {
//                List<SysMenu> sysMenu = menuService.selectMenuTreeByMenuId(s1);
//                menusByMenuID.addAll(sysMenu);
//            }
//            return AjaxResult.success(menuService.buildMenus(menusByMenuID));
//        }else{
            return AjaxResult.success(menuService.buildMenus(menus));
//        }
    }
}
