package com.ruoyi.system.service.impl;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import java.util.stream.Collectors;
import javax.validation.Validator;

import com.github.pagehelper.PageHelper;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.utils.PageUtils;
import com.ruoyi.system.mapper.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.bean.BeanValidators;
import com.ruoyi.common.utils.spring.SpringUtils;
import com.ruoyi.system.domain.SysPost;
import com.ruoyi.system.domain.SysUserPost;
import com.ruoyi.system.domain.SysUserRole;
import com.ruoyi.system.service.ISysConfigService;
import com.ruoyi.system.service.ISysUserService;

/**
 * 用户 业务层处理
 * 
 * @author ruoyi
 */
@Service
public class SysUserServiceImpl implements ISysUserService
{
    private static final Logger log = LoggerFactory.getLogger(SysUserServiceImpl.class);

    @Autowired
    private SysUserMapper userMapper;

    @Autowired
    private SysDeptMapper deptMapper;

    @Autowired
    private SysRoleMapper roleMapper;

    @Autowired
    private SysPostMapper postMapper;

    @Autowired
    private SysUserRoleMapper userRoleMapper;

    @Autowired
    private SysUserPostMapper userPostMapper;

    @Autowired
    private ISysConfigService configService;

    @Autowired
    protected Validator validator;

    /**
     * 根据条件分页查询用户列表
     * 
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    @Override
//    @DataScope(deptAlias = "d", userAlias = "u",roleAlias =)
    public List<SysUser> selectUserList(SysUser user)
    {
        if (user.getDeptId() != null){
            SysUser sysUser = new SysUser();
            PageHelper.clearPage();
            List<SysUser> sysUsers = userMapper.selectUserList(sysUser);
            PageUtils.startPage();
            List<SysUser> sysUsers1 = userMapper.selectUserList(user);
            for (SysUser sysUser1 : sysUsers) {
                if (sysUser1.getDeptId() != null && sysUser1.getDept().getDeptName() == null && sysUser1.getDeptId().contains(user.getDeptId())){
                    SysDept sysDept = new SysDept();
                    sysDept.setDeptId(user.getDeptId());
                    sysDept.setDeptName(deptMapper.selectDeptById(user.getDeptId()).getDeptName());
                    sysUser1.setDept(sysDept);
                    sysUsers1.add(sysUser1);
                }
            }
            Iterator<SysUser> iterator = sysUsers1.iterator();
            while(iterator.hasNext()){
                SysUser next = iterator.next();
                next.setUserName(next.getUserId());
                if (user.getStatus() == null && user.getUserName() == null){
                    continue;
                }else if (user.getStatus() != null && user.getUserName() != null){
                    if (next.getUserName().contains(user.getUserName()) && next.getStatus().equals(user.getStatus())){
                        continue;
                    }else{
                        iterator.remove();
                        if (sysUsers1.size() == 0){
                            return sysUsers1;
                        }
                    }
                }else if (user.getStatus() != null && user.getUserName() == null){
                    if (!next.getStatus().equals(user.getStatus())){
                        iterator.remove();
                        if (sysUsers1.size() == 0){
                            return sysUsers1;
                        }
                    }
                }else if (user.getStatus() == null && user.getUserName() != null){
                    if (!next.getUserName().contains(user.getUserName())){
                        iterator.remove();
                        if (sysUsers1.size() == 0){
                            return sysUsers1;
                        }
                    }
                }
            }
            return sysUsers1;
            }
        //应对sql语句遇到|时查询不出来的情况
        List<SysUser> sysUsers = userMapper.selectUserList(user);
        for (SysUser sysUser : sysUsers) {
            if (sysUser.getRoles().getRoleId() != null && sysUser.getRoles().getRoleName() == null){
                for (String s : sysUser.getRoles().getRoleId().split("\\|")) {
                    if (sysUser.getRoles().getRoleName() != null) {
                        sysUser.getRoles().setRoleName(sysUser.getRoles().getRoleName() + roleMapper.selectRoleById(s).getRoleName() + "|");
                    }else{
                        sysUser.getRoles().setRoleName(roleMapper.selectRoleById(s).getRoleName() + "|");
                    }
                }
                sysUser.getRoles().setRoleName(sysUser.getRoles().getRoleName().substring(0,sysUser.getRoles().getRoleName().length()-1));
            }
            if (sysUser.getDeptId() != null && sysUser.getDept().getDeptName() == null){
                for (String s : sysUser.getDept().getDeptId().split("\\|")) {
                    if (sysUser.getDept().getDeptName() != null) {
                        sysUser.getDept().setDeptName(sysUser.getDept().getDeptName() + deptMapper.selectDeptById(s).getDeptName() + "|");
                    }else{
                        sysUser.getDept().setDeptName(deptMapper.selectDeptById(s).getDeptName() + "|");
                    }
                }
                sysUser.getDept().setDeptName(sysUser.getDept().getDeptName().substring(0,sysUser.getDept().getDeptName().length()-1));
            }
        }
        for (SysUser sysUser : sysUsers) {
            sysUser.setUserName(sysUser.getUserId());
        }
        return sysUsers;
    }

    /**
     * 根据条件分页查询已分配用户角色列表
     * 
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<SysUser> selectAllocatedList(SysUser user)
    {
        return userMapper.selectAllocatedList(user);
    }

    /**
     * 根据条件分页查询未分配用户角色列表
     * 
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<SysUser> selectUnallocatedList(SysUser user)
    {
        return userMapper.selectUnallocatedList(user);
    }

    /**
     * 通过用户id查询用户
     * 
     * @param userId 用户id
     * @return 用户对象信息
     */
    @Override
    public SysUser selectUserByUserName(String userId)
    {
        return userMapper.selectUserByUserName(userId);
    }

    /**
     * 通过用户ID查询用户
     * 
     * @param userId 用户ID
     * @return 用户对象信息
     */
    @Override
    public SysUser selectUserById(String userId)
    {
        return userMapper.selectUserById(userId);
    }

    /**
     * 查询用户所属角色组
     * 
     * @param userName 用户名
     * @return 结果
     */
    @Override
    public String selectUserRoleGroup(String userName)
    {
        List<SysRole> list = roleMapper.selectRolesByUserName(userName);
        if (CollectionUtils.isEmpty(list))
        {
            return StringUtils.EMPTY;
        }
        return list.stream().map(SysRole::getRoleName).collect(Collectors.joining(","));
    }

    /**
     * 查询用户所属角色组
     *
     * @param userId 用户ID
     * @return 结果
     */
    @Override
    public String selectUserRoleIDsGroup(String userId)
    {
        String RolesIdsList = roleMapper.selectRoleIDsByUserName(userId);
        String result = "";
        if (StringUtils.isEmpty(RolesIdsList))
        {
            return StringUtils.EMPTY;
        }
        for (String s : RolesIdsList.split("\\|")) {
            String s1 = roleMapper.selectRoleName(s);
            result += s1 + " | ";
        }
        result = result.substring(0, result.length() - 3);
        return result;
    }

    /**
     * 查询用户所属岗位组
     * 
     * @param userName 用户名
     * @return 结果
     */
    @Override
    public String selectUserPostGroup(String userName)
    {
        List<SysPost> list = postMapper.selectPostsByUserName(userName);
        if (CollectionUtils.isEmpty(list))
        {
            return StringUtils.EMPTY;
        }
        return list.stream().map(SysPost::getPostName).collect(Collectors.joining(","));
    }

    /**
     * 校验用户名称是否唯一
     * 
     * @param userId 用户id
     * @return 结果
     */
    @Override
    public String checkUserNameUnique(String userId)
    {
        int count = userMapper.checkUserNameUnique(userId);
        if (count > 0)
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    /**
     * 校验手机号码是否唯一
     *
     * @param user 用户信息
     * @return
     */
    @Override
    public String checkPhoneUnique(SysUser user)
    {
        String userId = StringUtils.isNull(user.getUserId()) ? "-1L" : user.getUserId();
        SysUser info = userMapper.checkPhoneUnique(user.getPhonenumber());
        if (StringUtils.isNotNull(info) && info.getUserId().equals(userId))
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    /**
     * 校验email是否唯一
     *
     * @param user 用户信息
     * @return
     */
    @Override
    public String checkEmailUnique(SysUser user)
    {
        String userId = StringUtils.isNull(user.getUserId()) ? "-1L" : user.getUserId();
        SysUser info = userMapper.checkEmailUnique(user.getEmail());
        if (StringUtils.isNotNull(info) && info.getUserId().equals(userId))
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    /**
     * 校验用户是否允许操作
     * 
     * @param user 用户信息
     */
    @Override
    public void checkUserAllowed(SysUser user)
    {
        if (StringUtils.isNotNull(user.getUserId()) && user.isAdmin())
        {
            throw new ServiceException("不允许操作超级管理员用户");
        }
    }

    /**
     * 校验用户是否有数据权限
     * 
     * @param userId 用户id
     */
    @Override
    public void checkUserDataScope(String userId)
    {
        if (!SysUser.isAdmin(SecurityUtils.getUserId()))
        {
            SysUser user = new SysUser();
            user.setUserName(userId);
            List<SysUser> users = SpringUtils.getAopProxy(this).selectUserList(user);
            if (StringUtils.isEmpty(users))
            {
                throw new ServiceException("没有权限访问用户数据！");
            }
        }
    }

    /**
     * 新增保存用户信息
     * 
     * @param user 用户信息
     * @return 结果
     */
    @Override
    @Transactional
    public int insertUser(SysUser user)
    {
        // 新增用户信息
        String roleId = "";
        for (String id : user.getRoleIds()) {
            roleId += id + ("|");
        }
        roleId = roleId.substring(0,roleId.length()-1);
        user.setRoleId(roleId);
        int rows = userMapper.insertUser(user);
        // 新增用户岗位关联
        insertUserPost(user);
//        // 新增用户与角色管理
//        insertUserRole(user);
        return rows;
    }

    /**
     * 注册用户信息
     * 
     * @param user 用户信息
     * @return 结果
     */
    @Override
    public boolean registerUser(SysUser user)
    {
        return userMapper.insertUser(user) > 0;
    }

    /**
     * 修改保存用户信息
     * 
     * @param user 用户信息
     * @return 结果
     */
    @Override
    @Transactional
    public int updateUser(SysUser user)
    {
        String userId = user.getUserId();
        StringBuilder roleId = new StringBuilder();
        for (String id : user.getRoleIds()) {
            roleId.append(id).append("|");
        }
        String roleId1 = "";
        if (roleId.length() == 0){
            roleId1 = "";
        }else{
            roleId1 = roleId.substring(0, roleId.length() - 1);
        }
        user.setRoleId(roleId1);
//        // 删除用户与角色关联
//        userRoleMapper.deleteUserRoleByUserId(userId);
//        // 新增用户与角色管理
//        insertUserRole(user);
//        // 删除用户与岗位关联
//        userPostMapper.deleteUserPostByUserId(userId);
//        // 新增用户与岗位管理
//        insertUserPost(user);
        return userMapper.updateUser(user);
    }

    /**
     * 用户授权角色
     * 
     * @param userId 用户ID
     * @param roleIds 角色组
     */
    @Override
    @Transactional
    public void insertUserAuth(String userId, String[] roleIds)
    {
        userRoleMapper.deleteUserRoleByUserId(userId);
        insertUserRole(userId, roleIds);
    }

    /**
     * 修改用户状态
     * 
     * @param user 用户信息
     * @return 结果
     */
    @Override
    public int updateUserStatus(SysUser user)
    {
        return userMapper.updateUserStatus(user);
    }

    /**
     * 修改用户基本信息
     * 
     * @param user 用户信息
     * @return 结果
     */
    @Override
    public int updateUserProfile(SysUser user)
    {
        return userMapper.updateUser(user);
    }

    /**
     * 修改用户头像
     * 
     * @param userName 用户名
     * @param avatar 头像地址
     * @return 结果
     */
    @Override
    public boolean updateUserAvatar(String userName, String avatar)
    {
        return userMapper.updateUserAvatar(userName, avatar) > 0;
    }

    /**
     * 重置用户密码
     * 
     * @param user 用户信息
     * @return 结果
     */
    @Override
    public int resetPwd(SysUser user)
    {
        return userMapper.updateUser(user);
    }

    /**
     * 重置用户密码
     * 
     * @param userId 用户ID
     * @param password 密码
     * @return 结果
     */
    @Override
    public int resetUserPwd(String userId, String password)
    {
        return userMapper.resetUserPwd(userId, password);
    }

    /**
     * 新增用户角色信息
     * 
     * @param user 用户对象
     */
    public void insertUserRole(SysUser user)
    {
        String[] roles = user.getRoleIds();
        String roleSum = "";
        for (String role : roles) {
            roleSum += role + "|";

        }
        String roleSub = roleSum.substring(0, roleSum.length() - 1);
        if (!StringUtils.isEmpty(roleSub)){
            SysUserRole ur = new SysUserRole();
            ur.setUserId(user.getUserId());
            ur.setRoleId(roleSub);
            userRoleMapper.batchAddUserRoleMyself(ur);
        }
//        if (StringUtils.isNotNull(roles))
//        {
//            // 新增用户与角色管理
//            List<SysUserRole> list = new ArrayList<SysUserRole>();
//            for (String roleId : roles)
//            {
//                SysUserRole ur = new SysUserRole();
//                ur.setUserId(user.getUserName());
//                ur.setRoleId(roleId);
//                list.add(ur);
//            }
//            if (list.size() > 0)
//            {
//                userRoleMapper.batchUserRole(list);
//            }
//        }
    }

    /**
     * 新增用户岗位信息
     * 
     * @param user 用户对象
     */
    public void insertUserPost(SysUser user)
    {
        String[] posts = user.getPostIds();
        if (StringUtils.isNotNull(posts))
        {
            // 新增用户与岗位管理
            List<SysUserPost> list = new ArrayList<SysUserPost>();
            for (String postId : posts)
            {
                SysUserPost up = new SysUserPost();
                up.setUserId(user.getUserId());
                up.setPostId(postId);
                list.add(up);
            }
            if (list.size() > 0)
            {
                userPostMapper.batchUserPost(list);
            }
        }
    }

    /**
     * 新增用户角色信息
     * 
     * @param userId 用户ID
     * @param roleIds 角色组
     */
    public void insertUserRole(String userId, String[] roleIds)
    {
        if (StringUtils.isNotNull(roleIds))
        {
            // 新增用户与角色管理
            List<SysUserRole> list = new ArrayList<SysUserRole>();
            for (String roleId : roleIds)
            {
                SysUserRole ur = new SysUserRole();
                ur.setUserId(userId);
                ur.setRoleId(roleId);
                list.add(ur);
            }
            if (list.size() > 0)
            {
                userRoleMapper.batchUserRole(list);
            }
        }
    }

    /**
     * 通过用户ID删除用户
     * 
     * @param userId 用户ID
     * @return 结果
     */
    @Override
    @Transactional
    public int deleteUserById(String userId)
    {
        // 删除用户与角色关联
        //userRoleMapper.deleteUserRoleByUserId(userId);
        // 删除用户与岗位表
        //userPostMapper.deleteUserPostByUserId(userId);
        return userMapper.deleteUserById(userId);
    }

    /**
     * 批量删除用户信息
     * 
     * @param userIds 需要删除的用户ID
     * @return 结果
     */
    @Override
    @Transactional
    public int deleteUserByIds(String[] userIds)
    {
        for (String userId : userIds)
        {
            checkUserAllowed(new SysUser(userId));
            checkUserDataScope(userId);
        }
        // 删除用户与角色关联
        //userRoleMapper.deleteUserRole(userIds);
        // 删除用户与岗位关联
        //userPostMapper.deleteUserPost(userIds);
        return userMapper.deleteUserByIds(userIds);
    }

    /**
     * 导入用户数据
     * 
     * @param userList 用户数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    @Override
    public String importUser(List<SysUser> userList, Boolean isUpdateSupport, String operName)
    {
        if (StringUtils.isNull(userList) || userList.size() == 0)
        {
            throw new ServiceException("导入用户数据不能为空！");
        }
        int successNum = 0;
        int failureNum = 0;
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        String password = configService.selectConfigByKey("sys.user.initPassword");
        for (SysUser user : userList)
        {
            try
            {
                // 验证是否存在这个用户
                SysUser u = userMapper.selectUserByUserName(user.getUserId());
                if (StringUtils.isNull(u))
                {
                    BeanValidators.validateWithException(validator, user);
                    user.setPassword(SecurityUtils.encryptPassword(password));
                    user.setCreateBy(operName);
                    this.insertUser(user);
                    successNum++;
                    successMsg.append("<br/>" + successNum + "、账号 " + user.getUserId() + " 导入成功");
                }
                else if (isUpdateSupport)
                {
                    BeanValidators.validateWithException(validator, user);
//                    user.setUpdateBy(operName);
                    this.updateUser(user);
                    successNum++;
                    successMsg.append("<br/>" + successNum + "、账号 " + user.getUserId() + " 更新成功");
                }
                else
                {
                    failureNum++;
                    failureMsg.append("<br/>" + failureNum + "、账号 " + user.getUserId() + " 已存在");
                }
            }
            catch (Exception e)
            {
                failureNum++;
                String msg = "<br/>" + failureNum + "、账号 " + user.getUserId() + " 导入失败：";
                failureMsg.append(msg + e.getMessage());
                log.error(msg, e);
            }
        }
        if (failureNum > 0)
        {
            failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据格式不正确，错误如下：");
            throw new ServiceException(failureMsg.toString());
        }
        else
        {
            successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
        }
        return successMsg.toString();
    }
}
